import { Component, OnInit, Input } from '@angular/core';
import {
  Router,
  ActivatedRoute,
  ActivatedRouteSnapshot,
  NavigationEnd,
  Params,
  Event as RouterEvent,
  PRIMARY_OUTLET } from '@angular/router';
import 'rxjs/add/operator/filter';

// default 
const ROUTE_DATA_PARAM: string = 'navTitle';

interface NavTitle {
  label: string;
  url?: string;
}

@Component({
  selector: 'nav-title',
  templateUrl: './nav-title.component.html',
  styleUrls: ['./nav-title.component.css']
})
export class NavTitleComponent implements OnInit {
  @Input() splitChar: string = '–';
  @Input() dataParam: string = ROUTE_DATA_PARAM;

  titles: NavTitle[] = [];

  constructor(
    private activatedRouteSnapshot: ActivatedRoute,
    private router: Router) { }

  ngOnInit() {
    this.router.events
      .filter(event => event instanceof NavigationEnd)
      .subscribe(event => {
        this.titles = this.getNavTitle(this.activatedRouteSnapshot.snapshot);
      });
  }

  private getLastChildRoute(activatedSnapshot: ActivatedRouteSnapshot): ActivatedRouteSnapshot {
    let children = activatedSnapshot.children;
    if (children.length === 0) {
      return activatedSnapshot;
    }
    return this.getLastChildRoute(children[0])
  }

  private getNavTitle(activatedSnapshot: ActivatedRouteSnapshot): NavTitle[] {
    let pathFromRoute = this.getLastChildRoute(activatedSnapshot).pathFromRoot;
    let navTitle: NavTitle[] = [];
    
    for (let route of pathFromRoute) {
      if (route.data.hasOwnProperty(this.dataParam) && typeof route.data[this.dataParam] === 'string') {
        navTitle.push({
          label: route.data[this.dataParam],
          url: route.pathFromRoot.filter(r => r.url.length > 0).map(r => r.url[0]).join('/')
        });
      }
    }
    return navTitle;
  }
}